% Linearisation of model III in
% Geva-Zatorsky et al, Molecular Systems Biology (2006)
close all
clear all

% State variables
syms x y xi

bx=2.3;
by=24;
ax=0;
%ay=24;
ay=0.8;
axy=120;

f1 = bx*xi-ax*x-axy*x*y;
f2 = by*x*xi-ay*y;

% Compute the equilibrium point by simulating the nonlinear system
% Stimulus amplitude
xi_in=1;
%Tfin=1;
Tfin=10;
[tv,xv]=ode23s(@AlonIII,linspace(0,Tfin,401),[0,0],[],xi_in);
xe=xv(end,:);
plot(tv,xv)

% Compute dynamical matrix A at equilibrium point 0
% Jacobian matrix
Jac_fx=jacobian([f1;f2],[x,y]);
A_lin=subs(Jac_fx,[x,y,xi],[xe(1),xe(2),xi_in]);
% Compute input matrix of the linearised system
Jac_fu=jacobian([f1;f2],[xi]);
B_lin=subs(Jac_fu,[x,y,xi],[xe(1),xe(2),xi_in]);

% Build the linearised closed-loop system 
C_lin=[1,0];
D_lin=0;

AlonIII_sys=ss(A_lin,B_lin,C_lin,D_lin);
display(['dcgain: ', num2str(dcgain(AlonIII_sys))])
AlonIII_tf=tf(AlonIII_sys)
display('Poles: ')
pole(AlonIII_tf)
%[yv2,tv2]=step(2*s_in*behar3A_lin,Tfin);
%figure
%plot(tv2,yv2)

% Build the linearised open-loop system (fixed constant xi)
A_lin_ol=A_lin;
% y no longer enters the dx equation
A_lin_ol(1,2)=0;
% the dx equation has a new input u
% note that the sign is changed, because the minus is in the feedback path
B_lin_ol=[-A_lin(1,2);0];
C_lin_ol=[0,1];
D_lin_ol=0;

AlonIII_sys_ol=ss(A_lin_ol,B_lin_ol,C_lin_ol,D_lin_ol);
AlonIII_tf_ol=tf(AlonIII_sys_ol);
display(['dcgain: ', num2str(dcgain(AlonIII_sys_ol))])
display('Poles: ')
pole(AlonIII_tf_ol)