% Implementation of the bacterial chemotaxis model given in
% Barkai, Leibler, Nature, 1997.
%
% Script for the automatic writing of the model equations

% u is the ligand input

% Number of methylation sites
n_methyl=4;

% First iteration -> no demethylation terms
% Eu(1) means unoccupied receptor without methylated sited
% Eu(2) has 1 methylated site, and so on...
i=1;

dEu(i) = -kl*u*Eu(i)+kli*Eo(i)-ar*alph(i)*Eu(i)*cheR...
    -arp*(1-alph(i))*Eu(i)*cheR+dr*EuR(i)+kb*EuB(i+1);

dEuR(i) = -kl*u*EuR(i)+kli*EoR(i)+ar*alph(i)*Eu(i)*cheR...
    +arp*(1-alph(i))*Eu(i)*cheR-dr*EuR(i)-kr*EuR(i);

dEo(i) = kl*u*Eu(i)-kli*Eo(i)...
    -ar*alpho(i)*Eo(i)*cheR-arp*(1-alpho(i))*Eo(i)*cheR+dr*EoR(i)+kb*EoB(i+1);

dEoR(i) = kl*u*EuR(i)-kli*EoR(i)+ar*alpho(i)*Eo(i)*cheR...
    +arp*(1-alpho(i))*Eo(i)*cheR-dr*EoR(i)-kr*EoR(i);


for i=2:n_methyl
    dEu(i) = -kl*u*Eu(i)+kli*Eo(i)-ab*alph(i)*Eu(i)*CheB...
        -abp*(1-alph(i))*Eu(i)*CheB+db*EuB(i)+kr*EuR(i-1)...
        -ar*alph(i)*Eu(i)*cheR-arp*(1-alph(i))*Eu(i)*cheR+dr*EuR(i)+kb*EuB(i+1);
    
    dEuR(i) = -kl*u*EuR(i)+kli*EoR(i)+ar*alph(i)*Eu(i)*cheR...
        +arp*(1-alph(i))*Eu(i)*cheR-dr*EuR(i)-kr*EuR(i);
    
    dEuB(i) = -kl*u*EuB(i)+kli*EoB(i)+ab*alph(i)*Eu(i)*cheB+...
        abp*(1-au(i))*Eu(i)*cheB-db*EuB(i)-kb*EuB(i);
    
    dEo(i) = kl*u*Eu(i)-kli*Eo(i)-ab*alpho(i)*Eo(i)*CheB...
        -abp*(1-alpho(i))*Eo(i)*CheB+db*EoB(i)+kr*EoR(i-1)...
        -ar*alpho(i)*Eo(i)*cheR-arp*(1-alpho(i))*Eo(i)*cheR+dr*EoR(i)+kb*EoB(i+1);
    
    dEoR(i) = kl*u*EuR(i)-kli*EoR(i)+ar*alpho(i)*Eo(i)*cheR...
        +arp*(1-alpho(i))*Eo(i)*cheR-dr*EoR(i)-kr*EoR(i);
    
    dEoB(i) = kl*u*EuB(i)-kli*EoB(i)+ab*alpho(i)*Eo(i)*cheB+...
        abp*(1-alpho(i))*Eo(i)*cheB-db*EoB(i)-kb*EoB(i);
end

% Last iteration -> no methylation terms
i=n_methyl+1;

dEu(i) = -kl*u*Eu(i)+kli*Eo(i)-ab*alph(i)*Eu(i)*CheB...
    -abp*(1-alph(i))*Eu(i)*CheB+db*EuB(i)+kr*EuR(i-1);

dEuB(i) = -kl*u*EuB(i)+kli*EoB(i)+ab*alph(i)*Eu(i)*cheB+...
    abp*(1-au(i))*Eu(i)*cheB-db*EuB(i)-kb*EuB(i);

dEo(i) = kl*u*Eu(i)-kli*Eo(i)-ab*alpho(i)*Eo(i)*CheB...
    -abp*(1-alpho(i))*Eo(i)*CheB+db*EoB(i)+kr*EoR(i-1);

dEoB(i) = kl*u*EuB(i)-kli*EoB(i)+ab*alpho(i)*Eo(i)*cheB+...
    abp*(1-alpho(i))*Eo(i)*cheB-db*EoB(i)-kb*EoB(i);