% Figure for the example "Osmo-adaptation in S. cerevisiae"

% Experimental data (graphically derived from Mettetal et al, 2008
wv_wild=[
0.0486
0.0486
0.0969
0.0969
0.1946
0.1946
0.3907
0.3907
0.7768
0.7768
1.5628
1.5628
3.1258
3.1258
];

wv_low_Pbs2=wv_wild(1:end-2);

Mv_wild=[
-31.5925
-31.0010
-25.6257
-23.4710
-20.0124
-18.7335
-18.7725
-16.5521
-23.4710
-25.1177
-31.5410
-33.7721
-35.1967
-39.2948
];

Mv_low_Pbs2=[
-30.4823
-29.7380
-29.8943
-29.0914
-29.5230
-28.1517
-27.6437
-26.9384
-29.5035
-28.7397
-35.1825
-32.2640
];

Pv_wild=[
103.2937
100.1027
73.0869
69.4225
44.5603
23.4866
3.1007
-27.3540
-49.5440
-71.3505
-42.5194
-91.8041
-43.5117
-67.8777];

Pv_low_Pbs2=[
53.1972
35.6076
25.7868
14.8497
-2.7399
-9.5164
-30.2744
-36.6788
-33.5668
-36.2390
-34.3109
-46.6800];

%%%%%% Optimal models computed through the Curve Fitting
%%%%%% Toolbox

% Wild type model parameters
k=0.5396;
w_n=0.2787;
zeta=0.5144;

% Interpolant curve (wild type)
wv=logspace(-2,1,1000);
Mv_fit1=20*log10(abs(k.*1i.*wv))-20*log10(abs(1-wv.^2/w_n^2+1i*2*zeta/w_n.*wv));
Pv_fit1=180/pi*(angle(k*1i.*wv)-angle(1-wv.^2/w_n^2+1i*2*zeta/w_n.*wv));

% low Pbs2 model parameters
k=0.8885;
w_n=0.2131;
zeta=2.398;

% Interpolant curve (low Pbs2 model)
Mv_fit2=20*log10(k.*wv)-20*log10(abs(1-wv.^2/w_n^2+1i*2*zeta/w_n.*wv));
Pv_fit2=180/pi*(angle(k*1i.*wv)-angle(1-wv.^2/w_n^2+1i*2*zeta/w_n.*wv));

figure1=figure;

% Create axes for Magnitude plot
subplot(2,1,1,'Parent',figure1,'XScale','log','XMinorTick','on','FontSize',14);
hold on

plot(wv_wild,Mv_wild,'o',wv_low_Pbs2,Mv_low_Pbs2,'square','LineWidth',5,'MarkerSize',5);
plot(wv,Mv_fit1,wv,Mv_fit2,'LineWidth',2);

axis([1e-2,1e1,-42,-15]);

% Create xlabel
xlabel('\omega','FontSize',14);

% Create ylabel
ylabel('M(\omega)','FontSize',14);

% Create axes for Phase plot
subplot(2,1,2,'Parent',figure1,'XScale','log','XMinorTick','on','FontSize',14);
hold on

plot(wv_wild,Pv_wild,'o',wv_low_Pbs2,Pv_low_Pbs2,'square','LineWidth',5,'MarkerSize',5);
plot(wv,Pv_fit1,wv,Pv_fit2,'LineWidth',2);

axis([1e-2,1e1,-100,110]);

% Create xlabel
xlabel('\omega','FontSize',14);

% Create ylabel
ylabel('\phi(\omega)','FontSize',14);