% Figure for the example "Osmo-adaptation in S. cerevisiae"

% Experimental data (graphically derived from Mettetal et al, 2008
tv_wild=0:2:40;

tv_low_Pbs2=0:2:42;

yv_wild=[
    1.2175
    1.4817
    1.4741
    1.4023
    1.3332
    1.2813
    1.2487
    1.2271
    1.2198
    1.2170
    1.2227
    1.2319
    1.2233
    1.2227
    1.2251
    1.2304
    1.2278
    1.2181
    1.2208
    1.2232
    1.2346];

yv_low_Pbs2=[
    1.2301
    1.2891
    1.3041
    1.3103
    1.3145
    1.3075
    1.2958
    1.2929
    1.2955
    1.2796
    1.2742
    1.2693
    1.2617
    1.2523
    1.2474
    1.2473
    1.2402
    1.2348
    1.2299
    1.2448
    1.2410
    1.2411];

%%%%%% Optimal models computed through the Curve Fitting
%%%%%% Toolbox

% Wild type model parameters
k=4.238;
w_n=0.2787;
zeta=0.5144;

% Wild type model
s=tf('s');
Gs_wild=0.2*k*s/(s^2/w_n^2+2*zeta/w_n*s+1);

% Step Response of the model identified(wild type)
tv=linspace(0,44,1000);
step_resp_wild=step(Gs_wild,tv);

% low Pbs2 model parameters
k=6.978;
w_n=0.2131;
zeta=2.398;

% low Pbs2 model
s=tf('s');
Gs_low_Pbs2=0.2*k*s/(s^2/w_n^2+2*zeta/w_n*s+1);

% Step Response of the model identified(wild type)
tv=linspace(0,44,1000);
step_resp_low_Pbs2=step(Gs_low_Pbs2,tv);

figure1=figure;

% Create axes for Magnitude plot
axes('Parent',figure1,'XScale','linear','YTick',[1.2 1.3 1.4 1.5],...
    'XMinorTick','on','FontSize',14);
hold on

plot(tv_wild,yv_wild,'o',tv_low_Pbs2,yv_low_Pbs2,'square','LineWidth',5,'MarkerSize',5);
plot(tv,step_resp_wild+yv_wild(1),'-',tv,step_resp_low_Pbs2+yv_low_Pbs2(1),'--','LineWidth',2);

% Uncomment the following line and comment the previous one if you want to plot the
% response obtained with the nonlinear model used in the paper by Mettetal
% plot(tv,step_resp_wild+abs(step_resp_wild)+yv_wild(1),'-',tv,step_resp_low_Pbs2+abs(step_resp_low_Pbs2)+yv_low_Pbs2(1),'--','LineWidth',2);

axis([0,44,1.15,1.55]);

% Create xlabel
xlabel('Time [min]','FontSize',14);

% Create ylabel
ylabel('Response [Nuclear Hog1]','FontSize',14);

legend('meas. - wild type', 'meas. - low Pbs2','model - wild type','model - low Pbs2')

