% 3d surface plot of the Lyapunov function and its derivative for the
% Goldbeter system (with \beta=0.23)
%
% Run the Goldbeter linearisation script before

Npt=50;

% This Lyapunov matrix has been computed solving the Lyapunov equation
%                   A' P + P A = -Q
% with the A = Jacobian of the system and Q = lbd_val*I

lbd_val=10;
%P=lyap(A,lbd_val*eye(size(A)));
P=lyap(A,lbd_val*[1,0;0,.01]);

xmin=xe-0.7*xe;
xmax=xe+0.7*xe;

x1_v=linspace(xmin(1),xmax(1),Npt);
x2_v=linspace(xmin(2),xmax(2),Npt);

Lyap_fnc=zeros(Npt);
Lyap_fnc_deriv=zeros(Npt);

for i=1:Npt
    for j=1:Npt
        Lyap_fnc(i,j)=[x1_v(i)-xe(1), x2_v(j)-xe(2)]*P*[x1_v(i)-xe(1); x2_v(j)-xe(2)];
        Lyap_fnc_deriv(i,j)=Goldb_Lyap_fnc_deriv(x1_v(i),x2_v(j),P,xe);
    end
end


% Draw the Lyapunov function
figure
set(gcf,'OuterPosition',[136    75   800   699]);
surf(x1_v,x2_v,Lyap_fnc)
set(gca,'FontName','Times New Roman','FontSize',14,'CameraPosition',[2.2741 -24.0682 1.12937])
xlabel('x_1','FontSize',14)
ylabel('x_2','FontSize',14)
hold on
plot3(xe(1),xe(2),Goldb_Lyap_fnc_deriv(xe(1),xe(2),P,xe),'k.','MarkerSize',20)

% Draw the derivative of the Lyapunov function
figure
set(gcf,'OuterPosition',[136    75   800   699]);
surf(x1_v,x2_v,Lyap_fnc_deriv)
set(gca,'FontName','Times New Roman','FontSize',14,'CameraPosition',[-2.91272 -11.8541 32.641])
xlabel('x_1','FontName','Times New Roman','FontSize',14)
ylabel('x_2','FontName','Times New Roman','FontSize',14)
hold on
plot3(xe(1),xe(2),Goldb_Lyap_fnc_deriv(xe(1),xe(2),P,xe),'k.','MarkerSize',20)

figure
% Draw the Lyapunov function
set(gcf,'OuterPosition',[18, 153, 1233, 621]);
subplot(1,2,1)
[C,h]=contour(x1_v,x2_v,Lyap_fnc);
set(gca,'FontName','Times New Roman','FontSize',14)
clabel(C,h);
xlabel('x_1','FontName','Times New Roman','FontSize',14)
ylabel('x_2','FontName','Times New Roman','FontSize',14)
% Draw the derivative of the Lyapunov function
subplot(1,2,2)
[C,h]=contour(x1_v,x2_v,Lyap_fnc_deriv);
set(gca,'FontName','Times New Roman','FontSize',14)
clabel(C,h);
xlabel('x_1','FontName','Times New Roman','FontSize',14)
ylabel('x_2','FontName','Times New Roman','FontSize',14)
hold on
plot(xe(1),xe(2),'k.','MarkerSize',20)