% Linearization of the Goldbeter model
% Definition of the symbolic variables
syms x y

% Recall parameters
Goldbeter_params;
clear be
syms be

% Functions definition
Fx=v0+v1*be-V_M2*x^n/(K2^n+x^n)+V_M3*y^m/(K_R^m+y^m)*x^p/(K_A^p+x^p)+kf*y-k*x;
Fy=V_M2*x^n/(K2^n+x^n)-V_M3*y^m/(K_R^m+y^m)*x^p/(K_A^p+x^p)-kf*y;

% Compute the derivatives
dFx_dx=diff(Fx,'x');
dFx_dy=diff(Fx,'y');
dFy_dx=diff(Fy,'x');
dFy_dy=diff(Fy,'y');

dFx_du=diff(Fx,'be');
dFy_du=diff(Fy,'be');

% Compute the equilibrium point
xe=fsolve(@goldbeter_fnc,[0.1,0.1]);

% Compute the linearised model at the equilibrium point (note that the
% derivatives do not depend on beta)
A=[subs(dFx_dx,{x,y},[xe(1),xe(2)]), subs(dFx_dy,{x,y},[xe(1),xe(2)]);
   subs(dFy_dx,{x,y},[xe(1),xe(2)]), subs(dFy_dy,{x,y},[xe(1),xe(2)])];

B=[subs(dFx_du,{x,y},[xe(1),xe(2)]); subs(dFy_du,{x,y},[xe(1),xe(2)])];

%Compute the eigenvalues of linearised system
disp('Eigenvalues of the Jacobian: ')
disp(num2str(eigs(A)))